//+------------------------------------------------------------------+
//|                                         EMA-Crossover_Signal.mq4 |
//|                         |
//+------------------------------------------------------------------+

/*
  +------------------------------------------------------------------+
  | Allows you to enter two ema periods and it will then show you at |
  | Which point they crossed over. It is more usful on the shorter   |
  | periods that get obscured by the bars / candlesticks and when    |
  | the zoom level is out. Also allows you then to remove the emas   |
  | from the chart.              
  +------------------------------------------------------------------+
*/   

#property indicator_chart_window
#property indicator_buffers 2
#property indicator_color1 LightBlue
#property indicator_color2 Magenta

double CrossUp[];
double CrossDown[];
int CurrentTrend = 0;
datetime starttime = 0;
extern int Fast_MA_Period = 5; // Fast MA Period
extern int Fast_MA_Shift = 0; // Fast MA shift
extern ENUM_MA_METHOD Fast_MA_Method = MODE_EMA; //Fast MA Method
extern ENUM_APPLIED_PRICE Fast_MA_Price = PRICE_CLOSE; // Fast MA Price
extern int Slow_MA_Period = 8; // Slow MA Period
extern int Slow_MA_Shift = 0; // Slow MA shift
extern ENUM_MA_METHOD Slow_MA_Method = MODE_EMA; // Slow MA Method
extern ENUM_APPLIED_PRICE Slow_MA_Price = PRICE_OPEN; // Slow MA Price
extern bool Show_Alert = true;
extern bool Mobile_Push = true;
extern bool Play_Sound = false;
extern bool Send_Mail = false;

extern string SoundFilename = "alert.wav";

string TF, FMOD, SMOD;

int init()
{
   switch(Fast_MA_Method)
   {
     case MODE_SMA:  FMOD = " " + " FastMA-SMA-";  break;
     case MODE_EMA:  FMOD = " " + " FastMA-EMA-";  break;
     case MODE_SMMA: FMOD = " " + " FastMA-SMMA-"; break;
     case MODE_LWMA: FMOD = " " + " FastMA-LWMA-"; break;
   }
   
    switch(Slow_MA_Method)
   {
     case MODE_SMA:  SMOD = " " + " SlowMA-SMA-";  break;
     case MODE_EMA:  SMOD = " " + " SlowMA-EMA-";  break;
     case MODE_SMMA: SMOD = " " + " SlowMA-SMMA-"; break;
     case MODE_LWMA: SMOD = " " +  " SlowMA-LWMA-"; break;
   }
   
   int Minx = Period();
   string Miny = "M";
   string Minz = IntegerToString(Period());
   
   
   if(Period() < 60)
   {
     TF = StringConcatenate(Miny, Minz);
   }
   else if(Period() == 60)
   {
     TF = "H1";
   }
   else if(Period()== 240)
   {
     TF = "H4";
   }  
   else if(Period() == 1440)
   {
     TF = "D1";
   }
   else if(Period() == 10080)
   {
     TF = "W1";
   }
   else 
   {
     TF = "MN";
   } 
  
  SetIndexStyle(0, DRAW_ARROW, EMPTY);
  SetIndexArrow(0, 233);
  SetIndexBuffer(0, CrossUp);
  SetIndexStyle(1, DRAW_ARROW, EMPTY);
  SetIndexArrow(1, 234);
  SetIndexBuffer(1, CrossDown);
  starttime = TimeLocal();
   
  return(0);
}

int deinit()
{
   return(0);
}

int start() 
{
  int limit, i, counter, loop;
  double fasterEMAnow, slowerEMAnow, fasterEMAprevious, slowerEMAprevious, fasterEMAafter, slowerEMAafter;
  double Range, AvgRange;
  int counted_bars=IndicatorCounted();

  //---- check for possible errors
  if(counted_bars<0) return(-1);

  //---- last counted bar will be recounted
  if(counted_bars>0) counted_bars--;

  limit=Bars-counted_bars;
  //if(counted_bars==0) limit+=1;
  //if(counted_bars==0) limit=Bars+1;

  loop = 0;
  for(i = 0; i < limit; i++) 
  {
    counter=i;
    Range=0;
    AvgRange=0;
    for (counter=i ;counter<=i+9;counter++)
    {
      AvgRange=AvgRange+MathAbs(High[counter]-Low[counter]);
    }
    
    Range=AvgRange/10;
       
    fasterEMAnow = iMA(NULL, 0, Fast_MA_Period, Fast_MA_Shift, Fast_MA_Method, Fast_MA_Price, i);
    fasterEMAprevious = iMA(NULL, 0, Fast_MA_Period, Fast_MA_Shift, Fast_MA_Method, Fast_MA_Price, i+1);
    fasterEMAafter = iMA(NULL, 0, Fast_MA_Period, Fast_MA_Shift, Fast_MA_Method, Fast_MA_Price, i-1);

    slowerEMAnow = iMA(NULL, 0, Slow_MA_Period, Slow_MA_Shift, Slow_MA_Method, Slow_MA_Price, i);
    slowerEMAprevious = iMA(NULL, 0, Slow_MA_Period, Slow_MA_Shift, Slow_MA_Method, Slow_MA_Price, i+1);
    slowerEMAafter = iMA(NULL, 0, Slow_MA_Period, Slow_MA_Shift, Slow_MA_Method, Slow_MA_Price, i-1);
      
    if ((fasterEMAnow > slowerEMAnow) && (fasterEMAprevious < slowerEMAprevious) && (fasterEMAafter > slowerEMAafter)) 
    {
      CrossUp[i] = Low[i] - Range*0.5;

      if ((loop == 0) && (CurrentTrend != 1) && (TimeLocal() - starttime >= 10)) 
      {
        if (Show_Alert) 
        {
          Alert("Cross Up: " + Symbol() + "-" + TF + FMOD + IntegerToString(Fast_MA_Period) + " /" + SMOD + IntegerToString(Slow_MA_Period));
        }
        if (Mobile_Push) 
        {
          SendNotification("Cross Up:  " + Symbol() + "-" + TF + FMOD + IntegerToString(Fast_MA_Period) + " /" + SMOD + IntegerToString(Slow_MA_Period));
        }
        if (Play_Sound)  
        {
          PlaySound(SoundFilename);
        }
        if (Send_Mail)  
        {
          SendMail("MA Cross Up", "Cross Up: " + Symbol() + "-" + TF + FMOD + IntegerToString(Fast_MA_Period) + " /" + SMOD + IntegerToString(Slow_MA_Period));
        }
               
        CurrentTrend = 1;
      }

      if (loop == 0) 
      {
        loop = 1;
      }
    }
    else if ((fasterEMAnow < slowerEMAnow) && (fasterEMAprevious > slowerEMAprevious) && (fasterEMAafter < slowerEMAafter)) 
    {
      CrossDown[i] = High[i] + Range*0.5;

      if ((loop == 0) && (CurrentTrend != -1) && (TimeLocal() - starttime >= 10)) 
      {
        if (Show_Alert) 
        {
          Alert("Cross Down: " + Symbol() + "-" + TF + FMOD + IntegerToString(Fast_MA_Period) + " /" + SMOD + IntegerToString(Slow_MA_Period));
        }
        if (Mobile_Push) 
        {
          SendNotification("Cross Down: " + Symbol() + "-" + TF + FMOD + IntegerToString(Fast_MA_Period) + " /" + SMOD + IntegerToString(Slow_MA_Period) );
        }
        if (Play_Sound)  
        {
          PlaySound(SoundFilename);
        }
        if (Send_Mail) 
        {
          SendMail("MA Cross Down", "Cross Down: " + Symbol() + "-" + TF + FMOD + IntegerToString(Fast_MA_Period) + " /" + SMOD + IntegerToString(Slow_MA_Period));
        }
               
        CurrentTrend = -1;
      }

      if (loop == 0) 
      {
        loop = 1;
      }
    }
  }
  return(0);
}

